bloritsch 2002/06/13 10:24:52
Modified: component/src/java/org/apache/avalon/excalibur/component
DefaultComponentFactory.java
DefaultComponentManager.java
ExcaliburComponentManager.java
ExcaliburComponentSelector.java
component/src/test/org/apache/avalon/excalibur/component/test
ExcaliburComponentManagerTestCase.java
converter/src/java/org/apache/excalibur/converter/lib
StringToDateConverter.java
datasource build.xml
datasource/src/java/org/apache/avalon/excalibur/datasource
AbstractJdbcConnection.java J2eeDataSource.java
JdbcConnection.java JdbcDataSource.java
datasource/src/java/org/apache/avalon/excalibur/datasource/cluster
AbstractDataSourceCluster.java
datasource/src/java/org/apache/avalon/excalibur/datasource/ids
AbstractDataSourceIdGenerator.java
fortress/src/java/org/apache/excalibur/fortress
AbstractContainer.java
ContainerManagerConstants.java
fortress/src/java/org/apache/excalibur/fortress/handler
ComponentHandler.java
fortress/src/java/org/apache/excalibur/fortress/util
ContextManager.java
instrument/src/java/org/apache/avalon/excalibur/instrument
Instrumentable.java
instrument-manager/src/java/org/apache/avalon/excalibur/instrument/component
InstrumentComponentHandler.java
InstrumentComponentManager.java
InstrumentComponentSelector.java
instrument-manager/src/java/org/apache/avalon/excalibur/instrument/manager
InstrumentProxy.java
logger/src/test/org/apache/avalon/excalibur/logger/test
LogKitManagementTest.java
merlin/src/java/org/apache/excalibur/merlin
AbstractManager.java DefaultComponentManager.java
DefaultServiceManager.java DependencyInfo.java
ServiceFactory.java ServiceProvider.java
monitor/src/java/org/apache/avalon/excalibur/monitor
ActiveMonitor.java Monitor.java PassiveMonitor.java
sourceresolve/src/java/org/apache/excalibur/source
Source.java SourceResolver.java
sourceresolve/src/java/org/apache/excalibur/source/impl
SourceResolverImpl.java
store/src/java/org/apache/excalibur/store/impl
AbstractFilesystemStore.java MRUMemoryStore.java
testcase/src/java/org/apache/avalon/excalibur/testcase
ExcaliburTestCase.java
util/src/test/org/apache/excalibur/util/test
ComponentTestCase.java
Log:
more deprecation fixes--and a message to keep track of a newly deprecated JDK
method
Revision Changes Path
1.4 +4 -4
jakarta-avalon-excalibur/component/src/java/org/apache/avalon/excalibur/component/DefaultComponentFactory.java
Index: DefaultComponentFactory.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/component/src/java/org/apache/avalon/excalibur/component/DefaultComponentFactory.java,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -r1.3 -r1.4
--- DefaultComponentFactory.java 2 Jun 2002 06:03:01 -0000 1.3
+++ DefaultComponentFactory.java 13 Jun 2002 17:24:50 -0000 1.4
@@ -67,7 +67,7 @@
*/
private LogkitLoggerManager m_logkit;
- /** Components created by this factory, and their associated
ComponentManager
+ /** Components created by this factory, and their associated
ComponentLocator
* proxies, if they are Composables.
*/
private final BucketMap m_components = new BucketMap();
@@ -291,7 +291,7 @@
}
/**
- * Proxy <code>ComponentManager</code> class to maintain references to
+ * Proxy <code>ComponentLocator</code> class to maintain references to
* components looked up within a <code>Composable</code> instance created
* by this factory.
*
@@ -342,7 +342,7 @@
/**
* Releases all components that have been looked up through this
- * <code>ComponentManager</code>, that have not yet been released
+ * <code>ComponentLocator</code>, that have not yet been released
* via user code.
*/
private void releaseAll()
1.2 +2 -2
jakarta-avalon-excalibur/component/src/java/org/apache/avalon/excalibur/component/DefaultComponentManager.java
Index: DefaultComponentManager.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/component/src/java/org/apache/avalon/excalibur/component/DefaultComponentManager.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- DefaultComponentManager.java 4 Apr 2002 05:09:02 -0000 1.1
+++ DefaultComponentManager.java 13 Jun 2002 17:24:50 -0000 1.2
@@ -24,7 +24,7 @@
super();
}
- /** Create the ComponentManager with a Classloader */
+ /** Create the ComponentLocator with a Classloader */
public DefaultComponentManager( final ClassLoader loader )
{
super( loader );
1.7 +15 -15
jakarta-avalon-excalibur/component/src/java/org/apache/avalon/excalibur/component/ExcaliburComponentManager.java
Index: ExcaliburComponentSelector.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/component/src/java/org/apache/avalon/excalibur/component/ExcaliburComponentSelector.java,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -r1.6 -r1.7
--- ExcaliburComponentSelector.java 4 Jun 2002 08:02:16 -0000 1.6
+++ ExcaliburComponentSelector.java 13 Jun 2002 17:24:50 -0000 1.7
@@ -124,7 +124,7 @@
}
}
- /** Compose the ComponentSelector so that we know what the parent
ComponentManager is.
+ /** Compose the ComponentSelector so that we know what the parent
ComponentLocator is.
*/
public void compose( final ComponentManager componentManager )
throws ComponentException
@@ -237,7 +237,7 @@
{
if( getLogger().isWarnEnabled() )
{
- getLogger().warn( "Looking up component on an uninitialized
ComponentManager: " + hint );
+ getLogger().warn( "Looking up component on an uninitialized
ComponentLocator: " + hint );
}
}
@@ -437,7 +437,7 @@
// ThreadSafe components will always be using a
ThreadSafeComponentHandler,
// they will only have a single entry in the m_componentMapping map
which
- // should not be removed until the ComponentManager is disposed.
All
+ // should not be removed until the ComponentLocator is disposed.
All
// other components have an entry for each instance which should be
// removed.
if( !( handler instanceof ThreadSafeComponentHandler ) )
@@ -469,7 +469,7 @@
* @param componentClass Class of the component for which the handle is
* being requested.
* @param configuration The configuration for this component.
- * @param componentManager The ComponentManager which will be managing
+ * @param componentManager The ComponentLocator which will be managing
* the Component.
* @param context The current context object.
* @param roleManager The current RoleManager.
1.4 +2 -2
jakarta-avalon-excalibur/component/src/test/org/apache/avalon/excalibur/component/test/ExcaliburComponentManagerTestCase.java
Index: ExcaliburComponentManagerTestCase.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/component/src/test/org/apache/avalon/excalibur/component/test/ExcaliburComponentManagerTestCase.java,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -r1.3 -r1.4
--- ExcaliburComponentManagerTestCase.java 5 Jun 2002 21:34:03 -0000
1.3
+++ ExcaliburComponentManagerTestCase.java 13 Jun 2002 17:24:50 -0000
1.4
@@ -47,7 +47,7 @@
* involved: Mom, Dad, and Kid. Each of the three Roles can be
* implemented by a SingleThreaded, ThreadSafe, or Poolable component.
* The Mom and Dad components both are Composable, and they use the
- * ComponentManager that they are provided with to obtain references
+ * ComponentLocator that they are provided with to obtain references
* to a Kid component. The Mom and Dad components may be "Good" (they
* properly release their Kid) or "Bad" (they don't release their Kid).
*
1.3 +3 -1
jakarta-avalon-excalibur/converter/src/java/org/apache/excalibur/converter/lib/StringToDateConverter.java
Index: StringToDateConverter.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/converter/src/java/org/apache/excalibur/converter/lib/StringToDateConverter.java,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -r1.2 -r1.3
--- StringToDateConverter.java 13 May 2002 12:17:38 -0000 1.2
+++ StringToDateConverter.java 13 Jun 2002 17:24:50 -0000 1.3
@@ -7,6 +7,7 @@
*/
package org.apache.excalibur.converter.lib;
+import java.text.DateFormat;
import java.util.Date;
import org.apache.avalon.excalibur.i18n.ResourceManager;
import org.apache.avalon.excalibur.i18n.Resources;
@@ -51,7 +52,8 @@
{
try
{
- return new Date( object.toString() );
+ DateFormat formatter = DateFormat.getInstance();
+ return formatter.format( object.toString() );
}
catch( final NumberFormatException nfe )
{
1.21 +2 -2 jakarta-avalon-excalibur/datasource/build.xml
Index: build.xml
===================================================================
RCS file: /home/cvs/jakarta-avalon-excalibur/datasource/build.xml,v
retrieving revision 1.20
retrieving revision 1.21
diff -u -r1.20 -r1.21
--- build.xml 7 May 2002 15:47:58 -0000 1.20
+++ build.xml 13 Jun 2002 17:24:50 -0000 1.21
@@ -89,8 +89,8 @@
<target name="prepare-jdbc" depends="filter-jdbc,nofilter-jdbc"/>
<target name="filter-jdbc" unless="jdbc3.present">
- <filter token="JDBC3_START" value="/*"/>
- <filter token="JDBC3_END" value="*/"/>
+ <filter token="JDBC3_START" value="*/"/>
+ <filter token="JDBC3_END" value="/*"/>
</target>
<target name="nofilter-jdbc" if="jdbc3.present">
1.16 +3 -3
jakarta-avalon-excalibur/datasource/src/java/org/apache/avalon/excalibur/datasource/AbstractJdbcConnection.java
Index: AbstractJdbcConnection.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/datasource/src/java/org/apache/avalon/excalibur/datasource/AbstractJdbcConnection.java,v
retrieving revision 1.15
retrieving revision 1.16
diff -u -r1.15 -r1.16
--- AbstractJdbcConnection.java 10 Apr 2002 05:41:34 -0000 1.15
+++ AbstractJdbcConnection.java 13 Jun 2002 17:24:50 -0000 1.16
@@ -187,7 +187,7 @@
}
}
- @JDBC3_START@
+/* @JDBC3_START@
public abstract void setHoldability( int holdability )
throws SQLException;
@@ -234,5 +234,5 @@
public abstract PreparedStatement prepareStatement( String sql,
String[] columnNames
)
throws SQLException;
- @JDBC3_END@
+ @JDBC3_END@ */
}
1.9 +2 -9
jakarta-avalon-excalibur/datasource/src/java/org/apache/avalon/excalibur/datasource/J2eeDataSource.java
Index: J2eeDataSource.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/datasource/src/java/org/apache/avalon/excalibur/datasource/J2eeDataSource.java,v
retrieving revision 1.8
retrieving revision 1.9
diff -u -r1.8 -r1.9
--- J2eeDataSource.java 3 Jun 2002 00:23:21 -0000 1.8
+++ J2eeDataSource.java 13 Jun 2002 17:24:50 -0000 1.9
@@ -17,8 +17,6 @@
import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;
import org.apache.avalon.framework.logger.AbstractLogEnabled;
-import org.apache.avalon.framework.logger.LogKitLogger;
-import org.apache.avalon.framework.logger.Loggable;
/**
* The J2EE implementation for DataSources in Cocoon. This uses the
@@ -31,17 +29,12 @@
*/
public class J2eeDataSource
extends AbstractLogEnabled
- implements DataSourceComponent, Loggable
+ implements DataSourceComponent
{
public static final String JDBC_NAME = "java:comp/env/jdbc/";
protected DataSource m_dataSource = null;
protected String m_user;
protected String m_password;
-
- public void setLogger( org.apache.log.Logger logger )
- {
- enableLogging( new LogKitLogger( logger ) );
- }
/**
* Configure and set up DB connection. Here we set the connection
1.8 +3 -3
jakarta-avalon-excalibur/datasource/src/java/org/apache/avalon/excalibur/datasource/JdbcConnection.java
Index: JdbcConnection.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/datasource/src/java/org/apache/avalon/excalibur/datasource/JdbcConnection.java,v
retrieving revision 1.7
retrieving revision 1.8
diff -u -r1.7 -r1.8
--- JdbcConnection.java 16 Mar 2002 00:05:40 -0000 1.7
+++ JdbcConnection.java 13 Jun 2002 17:24:50 -0000 1.8
@@ -202,7 +202,7 @@
m_connection.setTypeMap( map );
}
- @JDBC3_START@
+/* @JDBC3_START@
public final void setHoldability( int holdability )
throws SQLException
{
@@ -285,6 +285,6 @@
{
throw new SQLException( "This is not a Jdbc 3.0 Compliant
Connection" );
}
- @JDBC3_END@
+ @JDBC3_END@ */
}
1.20 +2 -9
jakarta-avalon-excalibur/datasource/src/java/org/apache/avalon/excalibur/datasource/JdbcDataSource.java
Index: JdbcDataSource.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/datasource/src/java/org/apache/avalon/excalibur/datasource/JdbcDataSource.java,v
retrieving revision 1.19
retrieving revision 1.20
diff -u -r1.19 -r1.20
--- JdbcDataSource.java 2 May 2002 16:02:40 -0000 1.19
+++ JdbcDataSource.java 13 Jun 2002 17:24:50 -0000 1.20
@@ -14,8 +14,6 @@
import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;
import org.apache.avalon.framework.logger.AbstractLogEnabled;
-import org.apache.avalon.framework.logger.LogKitLogger;
-import org.apache.avalon.framework.logger.Loggable;
/**
* The Default implementation for DataSources in Avalon. This uses the
@@ -79,14 +77,9 @@
*/
public class JdbcDataSource
extends AbstractLogEnabled
- implements DataSourceComponent, Disposable, Loggable
+ implements DataSourceComponent, Disposable
{
protected JdbcConnectionPool m_pool;
-
- public void setLogger( final org.apache.log.Logger logger )
- {
- enableLogging( new LogKitLogger( logger ) );
- }
/**
* Configure and set up DB connection. Here we set the connection
1.2 +4 -4
jakarta-avalon-excalibur/datasource/src/java/org/apache/avalon/excalibur/datasource/cluster/AbstractDataSourceCluster.java
Index: AbstractDataSourceCluster.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/datasource/src/java/org/apache/avalon/excalibur/datasource/cluster/AbstractDataSourceCluster.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- AbstractDataSourceCluster.java 22 Apr 2002 03:04:27 -0000 1.1
+++ AbstractDataSourceCluster.java 13 Jun 2002 17:24:51 -0000 1.2
@@ -32,7 +32,7 @@
implements Composable, Configurable, Initializable, Disposable,
ThreadSafe
{
- /** ComponentManager which created this component */
+ /** ComponentLocator which created this component */
protected ComponentManager m_manager;
protected int m_size;
@@ -85,10 +85,10 @@
* Composable Methods
*-------------------------------------------------------------*/
/**
- * Called by the Container to tell the component which ComponentManager
+ * Called by the Container to tell the component which ComponentLocator
* is controlling it.
*
- * @param ComponentManager which curently owns the component.
+ * @param ComponentLocator which curently owns the component.
*/
public void compose( ComponentManager manager )
{
1.2 +4 -4
jakarta-avalon-excalibur/datasource/src/java/org/apache/avalon/excalibur/datasource/ids/AbstractDataSourceIdGenerator.java
Index: AbstractDataSourceIdGenerator.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/datasource/src/java/org/apache/avalon/excalibur/datasource/ids/AbstractDataSourceIdGenerator.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- AbstractDataSourceIdGenerator.java 22 Apr 2002 03:04:27 -0000
1.1
+++ AbstractDataSourceIdGenerator.java 13 Jun 2002 17:24:51 -0000
1.2
@@ -33,7 +33,7 @@
protected static final int DBTYPE_STANDARD = 0;
protected static final int DBTYPE_MYSQL = 1;
- /** ComponentManager which created this component */
+ /** ComponentLocator which created this component */
protected ComponentManager m_manager;
private String m_dataSourceName;
@@ -75,10 +75,10 @@
* Composable Methods
*-------------------------------------------------------------*/
/**
- * Called by the Container to tell the component which ComponentManager
+ * Called by the Container to tell the component which ComponentLocator
* is controlling it.
*
- * @param ComponentManager which curently owns the component.
+ * @param ComponentLocator which curently owns the component.
*/
public void compose( ComponentManager manager )
{
1.35 +5 -5
jakarta-avalon-excalibur/fortress/src/java/org/apache/excalibur/fortress/AbstractContainer.java
Index: AbstractContainer.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/fortress/src/java/org/apache/excalibur/fortress/AbstractContainer.java,v
retrieving revision 1.34
retrieving revision 1.35
diff -u -r1.34 -r1.35
--- AbstractContainer.java 13 May 2002 12:17:39 -0000 1.34
+++ AbstractContainer.java 13 Jun 2002 17:24:51 -0000 1.35
@@ -376,7 +376,7 @@
}
/**
- * Root ComponentManager. The Container may choose to have it's
ComponentManager
+ * Root ComponentLocator. The Container may choose to have it's
ComponentLocator
* delegate to the root manager, or it may choose to be entirely self
contained.
*/
public void compose( ComponentManager manager )
@@ -477,7 +477,7 @@
}
/**
- * This is the Default ComponentManager for the Container. It provides
+ * This is the Default ComponentLocator for the Container. It provides
* a very simple abstraction, and makes it easy for the Container to
manage
* the references.
*/
@@ -490,7 +490,7 @@
/**
* This constructor is for a ContainerComponentManager with no parent
- * ComponentManager
+ * ComponentLocator
*/
public ContainerComponentManager( final AbstractContainer container )
{
@@ -499,7 +499,7 @@
/**
* This constructor is for a ContainerComponentManager with a parent
- * ComponentManager
+ * ComponentLocator
*/
public ContainerComponentManager( final AbstractContainer container,
final ComponentManager parent )
{
1.6 +2 -2
jakarta-avalon-excalibur/fortress/src/java/org/apache/excalibur/fortress/ContainerManagerConstants.java
Index: ContainerManagerConstants.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/fortress/src/java/org/apache/excalibur/fortress/ContainerManagerConstants.java,v
retrieving revision 1.5
retrieving revision 1.6
diff -u -r1.5 -r1.6
--- ContainerManagerConstants.java 4 Apr 2002 16:04:28 -0000 1.5
+++ ContainerManagerConstants.java 13 Jun 2002 17:24:51 -0000 1.6
@@ -23,7 +23,7 @@
String CONTAINER_CLASS = "container.class";
/**
- * ComponentManager: The component manager to give to the container.
+ * ComponentLocator: The component manager to give to the container.
*/
String COMPONENT_MANAGER = "container.componentManager";
1.8 +2 -2
jakarta-avalon-excalibur/fortress/src/java/org/apache/excalibur/fortress/handler/ComponentHandler.java
Index: ComponentHandler.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/fortress/src/java/org/apache/excalibur/fortress/handler/ComponentHandler.java,v
retrieving revision 1.7
retrieving revision 1.8
diff -u -r1.7 -r1.8
--- ComponentHandler.java 4 Apr 2002 16:04:28 -0000 1.7
+++ ComponentHandler.java 13 Jun 2002 17:24:51 -0000 1.8
@@ -34,7 +34,7 @@
/**
* Sometimes Components call other components during their initialization
- * process. This is a quick test that the ComponentManager will perform
+ * process. This is a quick test that the ComponentLocator will perform
* before attempting to use the the ComponentHandler.
*/
boolean isInitialized();
1.21 +5 -5
jakarta-avalon-excalibur/fortress/src/java/org/apache/excalibur/fortress/util/ContextManager.java
Index: ContextManager.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/fortress/src/java/org/apache/excalibur/fortress/util/ContextManager.java,v
retrieving revision 1.20
retrieving revision 1.21
diff -u -r1.20 -r1.21
--- ContextManager.java 13 Jun 2002 12:59:10 -0000 1.20
+++ ContextManager.java 13 Jun 2002 17:24:51 -0000 1.21
@@ -48,7 +48,7 @@
* such as the pool manager etc. necessary for a child container to create
* additional child containers. The container manager context contains all
* of the child context, but also initialization parameters for the
- * container, such as a Configuration object, a ComponentManager, etc., that
+ * container, such as a Configuration object, a ComponentLocator, etc., that
* the container wants, but does not want to pass on to its children.
*
* <p>You would typically use the container manager context to initialize
@@ -255,7 +255,7 @@
}
/**
- * Will set up a ComponentManager if none is supplied.
+ * Will set up a ComponentLocator if none is supplied.
*
* The postcondition is that childContext.get(
Container.COMPONENT_MANAGER )
* should return a valid logger manager.
@@ -281,7 +281,7 @@
}
catch( ContextException ce )
{
- // No ComponentManager available anywhere. (Set one up.)
+ // No ComponentLocator available anywhere. (Set one up.)
}
//
@@ -382,7 +382,7 @@
}
/**
- * Get a reference to the initial ComponentManager used by the
ContainerManager
+ * Get a reference to the initial ComponentLocator used by the
ContainerManager
* to hold the Components used for parsing the config files and setting
up the
* environment.
*/
1.4 +2 -2
jakarta-avalon-excalibur/instrument/src/java/org/apache/avalon/excalibur/instrument/Instrumentable.java
Index: Instrumentable.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/instrument/src/java/org/apache/avalon/excalibur/instrument/Instrumentable.java,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -r1.3 -r1.4
--- Instrumentable.java 13 May 2002 12:28:36 -0000 1.3
+++ Instrumentable.java 13 Jun 2002 17:24:51 -0000 1.4
@@ -10,7 +10,7 @@
/**
* The Instrumentable interface is to mark objects that can be sampled by an
* InstrumentManager. The getInstruments method may or may not be called
- * depending on whether or not the ComponentManager used to create the
+ * depending on whether or not the ComponentLocator used to create the
* Component supports Instrumentables. In most cases, an instrumentable
* object should always create its internal Instruments and make use of them
* as if instrument data were being collected. The Instruments are
optimized
1.7 +2 -2
jakarta-avalon-excalibur/instrument-manager/src/java/org/apache/avalon/excalibur/instrument/component/InstrumentComponentHandler.java
Index: InstrumentComponentHandler.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/instrument-manager/src/java/org/apache/avalon/excalibur/instrument/component/InstrumentComponentHandler.java,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -r1.6 -r1.7
--- InstrumentComponentHandler.java 4 Jun 2002 06:40:39 -0000 1.6
+++ InstrumentComponentHandler.java 13 Jun 2002 17:24:51 -0000 1.7
@@ -44,7 +44,7 @@
* @param componentClass Class of the component for which the handle is
* being requested.
* @param configuration The configuration for this component.
- * @param componentManager The ComponentManager which will be managing
+ * @param componentManager The ComponentLocator which will be managing
* the Component.
* @param context The current context object.
* @param roleManager The current RoleManager.
1.5 +2 -2
jakarta-avalon-excalibur/instrument-manager/src/java/org/apache/avalon/excalibur/instrument/component/InstrumentComponentManager.java
Index: InstrumentComponentManager.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/instrument-manager/src/java/org/apache/avalon/excalibur/instrument/component/InstrumentComponentManager.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- InstrumentComponentManager.java 4 Jun 2002 06:40:39 -0000 1.4
+++ InstrumentComponentManager.java 13 Jun 2002 17:24:51 -0000 1.5
@@ -108,7 +108,7 @@
* manager with the InstrumentManager.
*
* @throws Exception If there are any problems initializing the
- * ComponentManager.
+ * ComponentLocator.
*/
public void initialize()
throws Exception
1.5 +2 -2
jakarta-avalon-excalibur/instrument-manager/src/java/org/apache/avalon/excalibur/instrument/component/InstrumentComponentSelector.java
Index: InstrumentComponentSelector.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/instrument-manager/src/java/org/apache/avalon/excalibur/instrument/component/InstrumentComponentSelector.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- InstrumentComponentSelector.java 4 Jun 2002 06:40:39 -0000 1.4
+++ InstrumentComponentSelector.java 13 Jun 2002 17:24:51 -0000 1.5
@@ -67,7 +67,7 @@
* @param componentClass Class of the component for which the handle is
* being requested.
* @param configuration The configuration for this component.
- * @param componentManager The ComponentManager which will be managing
+ * @param componentManager The ComponentLocator which will be managing
* the Component.
* @param context The current context object.
* @param roleManager The current RoleManager.
1.9 +2 -2
jakarta-avalon-excalibur/instrument-manager/src/java/org/apache/avalon/excalibur/instrument/manager/InstrumentProxy.java
Index: InstrumentProxy.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/instrument-manager/src/java/org/apache/avalon/excalibur/instrument/manager/InstrumentProxy.java,v
retrieving revision 1.8
retrieving revision 1.9
diff -u -r1.8 -r1.9
--- InstrumentProxy.java 13 Jun 2002 13:06:27 -0000 1.8
+++ InstrumentProxy.java 13 Jun 2002 17:24:51 -0000 1.9
@@ -29,7 +29,7 @@
/**
* Instrumentables which do not implement ThreadSafe may have multiple
instances
- * created by the ComponentManager. Each of these Instruments will share
+ * created by the ComponentLocator. Each of these Instruments will share
* a common key and are profiled as a group. The InstrumentProxy is used
* make it easy for the InstrumentManager to control groups of Instruments
* as one.
1.2 +4 -4
jakarta-avalon-excalibur/logger/src/test/org/apache/avalon/excalibur/logger/test/LogKitManagementTest.java
Index: LogKitManagementTest.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/logger/src/test/org/apache/avalon/excalibur/logger/test/LogKitManagementTest.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- LogKitManagementTest.java 4 Apr 2002 02:34:16 -0000 1.1
+++ LogKitManagementTest.java 13 Jun 2002 17:24:51 -0000 1.2
@@ -72,7 +72,7 @@
}
/**
- * Initializes the ComponentManager
+ * Initializes the ComponentLocator
*
* The configuration file is determined by the class name plus .xtest
appended,
* all '.' replaced by '/' and loaded as a resource via classpath
@@ -86,7 +86,7 @@
}
/**
- * Initializes the ComponentManager
+ * Initializes the ComponentLocator
*
* @param testconf The configuration file is passed as a
<code>InputStream</code> *
* A common way to supply a InputStream is to overwrite the initialize()
method
@@ -113,7 +113,7 @@
}
/**
- * Disposes the <code>ComponentManager</code>
+ * Disposes the <code>ComponentLocator</code>
*/
final private void dispose()
{
1.4 +1 -1
jakarta-avalon-excalibur/merlin/src/java/org/apache/excalibur/merlin/AbstractManager.java
Index: AbstractManager.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/merlin/src/java/org/apache/excalibur/merlin/AbstractManager.java,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -r1.3 -r1.4
--- AbstractManager.java 13 Jun 2002 12:59:10 -0000 1.3
+++ AbstractManager.java 13 Jun 2002 17:24:51 -0000 1.4
@@ -14,7 +14,7 @@
/**
* Internal helper class the handles the functional requirements of
- * both ComponetManager and ComponentManager.
+ * both ComponetManager and ComponentLocator.
* @author <a href="mailto:[EMAIL PROTECTED]">Stephen McConnell</a>
*/
class AbstractManager
1.4 +1 -1
jakarta-avalon-excalibur/merlin/src/java/org/apache/excalibur/merlin/DefaultComponentManager.java
Index: DefaultComponentManager.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/merlin/src/java/org/apache/excalibur/merlin/DefaultComponentManager.java,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -r1.3 -r1.4
--- DefaultComponentManager.java 12 May 2002 13:41:28 -0000 1.3
+++ DefaultComponentManager.java 13 Jun 2002 17:24:51 -0000 1.4
@@ -15,7 +15,7 @@
import org.apache.avalon.framework.component.ComponentManager;
/**
- * Internal helper class the implements the <code>ComponentManager</code>
interface and
+ * Internal helper class the implements the <code>ComponentLocator</code>
interface and
* is supplied to dynamically created componets during lifecycle pipeline
processing.
* @author Stephen McConnell <[EMAIL PROTECTED]>
*/
1.4 +3 -3
jakarta-avalon-excalibur/merlin/src/java/org/apache/excalibur/merlin/DefaultServiceManager.java
Index: DefaultServiceManager.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/merlin/src/java/org/apache/excalibur/merlin/DefaultServiceManager.java,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -r1.3 -r1.4
--- DefaultServiceManager.java 13 Jun 2002 12:59:10 -0000 1.3
+++ DefaultServiceManager.java 13 Jun 2002 17:24:51 -0000 1.4
@@ -14,7 +14,7 @@
import org.apache.avalon.framework.service.ServiceManager;
/**
- * Internal helper class the implements the <code>ComponentManager</code>
interface and
+ * Internal helper class the implements the <code>ComponentLocator</code>
interface and
* is supplied to dynamically created componets during lifecyle pipeline
processing.
* @author Stephen McConnell <[EMAIL PROTECTED]>
*/
@@ -23,7 +23,7 @@
implements ServiceManager
{
/**
- * Construct ComponentManager.
+ * Construct ComponentLocator.
*/
public DefaultServiceManager( Map providers )
{
@@ -41,7 +41,7 @@
}
/**
- * Retrieve Object by role from ComponentManager.
+ * Retrieve Object by role from ComponentLocator.
* @param role the role
* @return the Object
* @exception ComponentException if an error occurs
1.4 +1 -1
jakarta-avalon-excalibur/merlin/src/java/org/apache/excalibur/merlin/DependencyInfo.java
Index: DependencyInfo.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/merlin/src/java/org/apache/excalibur/merlin/DependencyInfo.java,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -r1.3 -r1.4
--- DependencyInfo.java 13 Jun 2002 12:59:10 -0000 1.3
+++ DependencyInfo.java 13 Jun 2002 17:24:51 -0000 1.4
@@ -40,7 +40,7 @@
* Returns the role name that the component uses to lookup a
* the dependency.
* @return the dependecy role name
- * @see org.apache.avalon.framework.service.ComponentManager
+ * @see org.apache.avalon.framework.service.ComponentLocator
* @see org.apache.avalon.framework.service.Composable
*/
public String getRole()
1.7 +5 -5
jakarta-avalon-excalibur/merlin/src/java/org/apache/excalibur/merlin/ServiceFactory.java
Index: ServiceFactory.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/merlin/src/java/org/apache/excalibur/merlin/ServiceFactory.java,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -r1.6 -r1.7
--- ServiceFactory.java 13 Jun 2002 12:59:10 -0000 1.6
+++ ServiceFactory.java 13 Jun 2002 17:24:51 -0000 1.7
@@ -130,11 +130,11 @@
}
/**
- * Dynamic creation of a <code>ComponentManager</code> based on a set of
+ * Dynamic creation of a <code>ComponentLocator</code> based on a set of
* supplied dependencies and container configuration.
* @param info meta information about the service
* @param base the base logger
- * @return ComponentManager a new service manager
+ * @return ComponentLocator a new service manager
*/
private ServiceManager createServiceManager( UnitInfo info, Logger base )
throws ServiceException
@@ -143,11 +143,11 @@
}
/**
- * Dynamic creation of a <code>ComponentManager</code> based on a set of
+ * Dynamic creation of a <code>ComponentLocator</code> based on a set of
* supplied dependencies and container configuration.
* @param info meta information about the component
* @param base the base logger
- * @return ComponentManager a new component manager
+ * @return ComponentLocator a new component manager
*/
private ComponentManager createComponentManager( UnitInfo info, Logger
base )
throws ServiceException
@@ -179,7 +179,7 @@
catch( Throwable e )
{
final String error =
- "Unexpected exception while attempting to create a
ComponentManager.";
+ "Unexpected exception while attempting to create a
ComponentLocator.";
throw new ServiceException( error, e );
}
}
1.4 +4 -4
jakarta-avalon-excalibur/merlin/src/java/org/apache/excalibur/merlin/ServiceProvider.java
Index: ServiceProvider.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/merlin/src/java/org/apache/excalibur/merlin/ServiceProvider.java,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -r1.3 -r1.4
--- ServiceProvider.java 13 Jun 2002 12:59:10 -0000 1.3
+++ ServiceProvider.java 13 Jun 2002 17:24:52 -0000 1.4
@@ -15,10 +15,10 @@
/**
* <code>ServiceProvider</code> is an abstract base class to services
* factories. The abstract class provides the single <code>getRole</code>
- * method that can be used by a <code>ComponentManager</code> implementation
+ * method that can be used by a <code>ComponentLocator</code> implementation
* to identity a service provider for a particular role.
* A concrete <code>ServiceProvider</code> instance will typically be
- * created by an implementation when constructing a
<code>ComponentManager</code>
+ * created by an implementation when constructing a
<code>ComponentLocator</code>
* for a target component.
* @author <a href="mailto:[EMAIL PROTECTED]">Stephen McConnell</a>
*/
@@ -30,7 +30,7 @@
* Creation of a new <code>ServiceProvider</code> instance based on
* a supplied role.
* @param role the role of the service provided by the provider relative
- * to a <code>ComponentManager</code> that is exposing provider
services.
+ * to a <code>ComponentLocator</code> that is exposing provider
services.
*/
public ServiceProvider( String role )
{
@@ -38,7 +38,7 @@
}
/**
- * Returns the role of this provider within the scope of a
<code>ComponentManager</code>.
+ * Returns the role of this provider within the scope of a
<code>ComponentLocator</code>.
* @return String the role of the service provider by the provider.
*/
public String getRole()
1.12 +2 -2
jakarta-avalon-excalibur/monitor/src/java/org/apache/avalon/excalibur/monitor/ActiveMonitor.java
Index: ActiveMonitor.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/monitor/src/java/org/apache/avalon/excalibur/monitor/ActiveMonitor.java,v
retrieving revision 1.11
retrieving revision 1.12
diff -u -r1.11 -r1.12
--- ActiveMonitor.java 13 May 2002 12:17:40 -0000 1.11
+++ ActiveMonitor.java 13 Jun 2002 17:24:52 -0000 1.12
@@ -20,7 +20,7 @@
/**
* The ActiveMonitor is used to actively check a set of resources to see if
they have
* changed. It will be implemented as a Component, that can be retrieved
from
- * the ComponentManager. It defaults to checking every 1 minute. The
configuration
+ * the ComponentLocator. It defaults to checking every 1 minute. The
configuration
* looks like this:
*
* <pre>
1.8 +2 -2
jakarta-avalon-excalibur/monitor/src/java/org/apache/avalon/excalibur/monitor/Monitor.java
Index: Monitor.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/monitor/src/java/org/apache/avalon/excalibur/monitor/Monitor.java,v
retrieving revision 1.7
retrieving revision 1.8
diff -u -r1.7 -r1.8
--- Monitor.java 13 May 2002 12:17:40 -0000 1.7
+++ Monitor.java 13 Jun 2002 17:24:52 -0000 1.8
@@ -12,7 +12,7 @@
/**
* The Monitor is used to actively check a set of resources to see if they
have
* changed. It will be implemented as a Component, that can be retrieved
from
- * the ComponentManager.
+ * the ComponentLocator.
*
* @author <a href="mailto:[EMAIL PROTECTED]">Berin Loritsch</a>
* @version $Id$
1.10 +2 -2
jakarta-avalon-excalibur/monitor/src/java/org/apache/avalon/excalibur/monitor/PassiveMonitor.java
Index: PassiveMonitor.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/monitor/src/java/org/apache/avalon/excalibur/monitor/PassiveMonitor.java,v
retrieving revision 1.9
retrieving revision 1.10
diff -u -r1.9 -r1.10
--- PassiveMonitor.java 13 Jun 2002 12:59:10 -0000 1.9
+++ PassiveMonitor.java 13 Jun 2002 17:24:52 -0000 1.10
@@ -20,7 +20,7 @@
/**
* The PassiveMonitor is used to passively check a set of resources to see
if they have
* changed. It will be implemented as a Component, that can be retrieved
from
- * the ComponentManager. It defaults to checking every 1 minute. The
configuration
+ * the ComponentLocator. It defaults to checking every 1 minute. The
configuration
* looks like this:
*
* <pre>
1.6 +2 -2
jakarta-avalon-excalibur/sourceresolve/src/java/org/apache/excalibur/source/Source.java
Index: Source.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/sourceresolve/src/java/org/apache/excalibur/source/Source.java,v
retrieving revision 1.5
retrieving revision 1.6
diff -u -r1.5 -r1.6
--- Source.java 12 Jun 2002 09:24:14 -0000 1.5
+++ Source.java 13 Jun 2002 17:24:52 -0000 1.6
@@ -17,7 +17,7 @@
*
* When the <code>Source</code> object is no longer needed
* it must be released using the resolver. This is very similar like
- * looking up components from a <code>ComponentManager</code>.
+ * looking up components from a <code>ComponentLocator</code>.
* In fact a source object can implement most lifecycle interfaces
* like Composable, Initializable, Disposable etc.
*
1.5 +2 -2
jakarta-avalon-excalibur/sourceresolve/src/java/org/apache/excalibur/source/SourceResolver.java
Index: SourceResolver.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/sourceresolve/src/java/org/apache/excalibur/source/SourceResolver.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- SourceResolver.java 13 May 2002 12:17:40 -0000 1.4
+++ SourceResolver.java 13 Jun 2002 17:24:52 -0000 1.5
@@ -24,7 +24,7 @@
*
* When the <code>Source</code> object is no longer needed
* it must be released using the resolver. This is very similar like
- * looking up components from a <code>ComponentManager</code>.
+ * looking up components from a <code>ComponentLocator</code>.
* In fact a source object can implement most lifecycle interfaces
* like Composable, Initializable, Disposable etc.
*
1.9 +3 -3
jakarta-avalon-excalibur/sourceresolve/src/java/org/apache/excalibur/source/impl/SourceResolverImpl.java
Index: SourceResolverImpl.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/sourceresolve/src/java/org/apache/excalibur/source/impl/SourceResolverImpl.java,v
retrieving revision 1.8
retrieving revision 1.9
diff -u -r1.8 -r1.9
--- SourceResolverImpl.java 13 Jun 2002 12:59:10 -0000 1.8
+++ SourceResolverImpl.java 13 Jun 2002 17:24:52 -0000 1.9
@@ -45,7 +45,7 @@
*
* When the <code>Source</code> object is no longer needed
* it must be released using the resolver. This is very similar like
- * looking up components from a <code>ComponentManager</code>
+ * looking up components from a <code>ComponentLocator</code>
* and releasing them.
*
* It looks for the base URL in the <code>Context</code> object with
@@ -120,7 +120,7 @@
}
/**
- * Set the current <code>ComponentManager</code> instance used by this
+ * Set the current <code>ComponentLocator</code> instance used by this
* <code>Composable</code>.
*/
public void compose( ComponentManager manager )
1.3 +3 -1
jakarta-avalon-excalibur/store/src/java/org/apache/excalibur/store/impl/AbstractFilesystemStore.java
Index: AbstractFilesystemStore.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/store/src/java/org/apache/excalibur/store/impl/AbstractFilesystemStore.java,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -r1.2 -r1.3
--- AbstractFilesystemStore.java 6 May 2002 12:16:15 -0000 1.2
+++ AbstractFilesystemStore.java 13 Jun 2002 17:24:52 -0000 1.3
@@ -298,7 +298,9 @@
}
filename = out.toString();
}
+ // In JDK 1.4 this is deprecated, the new format is below
return java.net.URLDecoder.decode( filename );
+ // return java.net.URLDecoder.decode( filename, "UTF-8" );
}
/** A BitSet defining the characters which don't need encoding */
1.4 +3 -3
jakarta-avalon-excalibur/store/src/java/org/apache/excalibur/store/impl/MRUMemoryStore.java
Index: MRUMemoryStore.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/store/src/java/org/apache/excalibur/store/impl/MRUMemoryStore.java,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -r1.3 -r1.4
--- MRUMemoryStore.java 7 May 2002 21:42:38 -0000 1.3
+++ MRUMemoryStore.java 13 Jun 2002 17:24:52 -0000 1.4
@@ -50,9 +50,9 @@
private ComponentManager manager;
/**
- * Get components of the ComponentManager
+ * Get components of the ComponentLocator
*
- * @param manager The ComponentManager
+ * @param manager The ComponentLocator
*/
public void compose(ComponentManager manager)
throws ComponentException {
1.4 +7 -7
jakarta-avalon-excalibur/testcase/src/java/org/apache/avalon/excalibur/testcase/ExcaliburTestCase.java
Index: ExcaliburTestCase.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/testcase/src/java/org/apache/avalon/excalibur/testcase/ExcaliburTestCase.java,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -r1.3 -r1.4
--- ExcaliburTestCase.java 25 Apr 2002 13:46:00 -0000 1.3
+++ ExcaliburTestCase.java 13 Jun 2002 17:24:52 -0000 1.4
@@ -45,7 +45,7 @@
* <dl>
* <dt>manager</dt>
* <dd>
- * This instance variable contains an initialized ComponentManager which
+ * This instance variable contains an initialized ComponentLocator which
* can be used to lookup Components configured in the test configuration
* file. (see below)
* </dd>
@@ -202,7 +202,7 @@
*
* <dt>components</dt>
* <dd>Used to configure any Components used by the test cases. The logger
- * used by the ComponentManager can be configured using a
<code>logger</code>
+ * used by the ComponentLocator can be configured using a
<code>logger</code>
* attribute, which defaults to "cm". By default this logger will have the
* same log level and formatting as the LogKit logger. It can be configured
* by adding a <code>category</code> within the <code>logkit</code> element.
@@ -277,7 +277,7 @@
}
/**
- * Initializes the ComponentManager
+ * Initializes the ComponentLocator
*
* The configuration file is determined by the class name plus .xtest
appended,
* all '.' replaced by '/' and loaded as a resource via classpath
@@ -300,7 +300,7 @@
}
/**
- * Initializes the ComponentManager
+ * Initializes the ComponentLocator
*
* @param testconf The configuration file is passed as a
<code>InputStream</code>
*
@@ -337,7 +337,7 @@
}
/**
- * Disposes the <code>ComponentManager</code>
+ * Disposes the <code>ComponentLocator</code>
*/
final private void done()
{
@@ -565,7 +565,7 @@
roleManager.setLogger( logKitManager.getLogger( rmLoggerName ) );
roleManager.configure( confRM );
- // Set up the ComponentManager
+ // Set up the ComponentLocator
String cmLoggerName = confCM.getAttribute( "logger", "cm" );
ExcaliburComponentManager manager = new ExcaliburComponentManager();
manager.setLogger( logKitManager.getLogger( cmLoggerName ) );
1.3 +2 -2
jakarta-avalon-excalibur/util/src/test/org/apache/excalibur/util/test/ComponentTestCase.java
Index: ComponentTestCase.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/util/src/test/org/apache/excalibur/util/test/ComponentTestCase.java,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -r1.2 -r1.3
--- ComponentTestCase.java 2 May 2002 16:54:23 -0000 1.2
+++ ComponentTestCase.java 13 Jun 2002 17:24:52 -0000 1.3
@@ -210,6 +210,6 @@
return;
}
- fail( "Did not detect double assignment of ComponentManager" );
+ fail( "Did not detect double assignment of ComponentLocator" );
}
}
Index: ExcaliburComponentManager.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-excalibur/component/src/java/org/apache/avalon/excalibur/component/ExcaliburComponentManager.java,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -r1.6 -r1.7
--- ExcaliburComponentManager.java 2 Jun 2002 06:03:01 -0000 1.6
+++ ExcaliburComponentManager.java 13 Jun 2002 17:24:50 -0000 1.7
@@ -45,7 +45,7 @@
RoleManageable,
LogKitManageable
{
/** The parent ComponentManager */
private final ComponentManager m_parentManager;
/** The classloader used for this system. */
@@ -72,19 +72,19 @@
/** Is the Manager initialized? */
private boolean m_initialized;
/** Create the ComponentManager */
public ExcaliburComponentManager()
{
this( null, Thread.currentThread().getContextClassLoader() );
}
/** Create the ComponentManager with a Classloader */
public ExcaliburComponentManager( final ClassLoader loader )
{
this( null, loader );
}
- /** Create the ComponentManager with a Classloader and parent
ComponentManager */
+ /** Create the ComponentLocator with a Classloader and parent
ComponentLocator */
public ExcaliburComponentManager( final ComponentManager manager, final
ClassLoader loader )
{
if( null == loader )
@@ -99,7 +99,7 @@
m_parentManager = manager;
}
/** Create the ComponentManager with a parent ComponentManager */
public ExcaliburComponentManager( final ComponentManager manager )
{
this( manager, Thread.currentThread().getContextClassLoader() );
@@ -240,19 +240,19 @@
{
if( getLogger().isWarnEnabled() )
{
- getLogger().warn( "Looking up component on an uninitialized
ComponentManager: " + role );
+ getLogger().warn( "Looking up component on an uninitialized
ComponentLocator: " + role );
}
}
if( m_disposed )
{
- throw new IllegalStateException( "You cannot lookup components
on a disposed ComponentManager" );
+ throw new IllegalStateException( "You cannot lookup components
on a disposed ComponentLocator" );
}
if( null == role )
{
final String message =
- "ComponentManager Attempted to retrieve component with null
role.";
+ "ComponentLocator Attempted to retrieve component with null
role.";
if( getLogger().isErrorEnabled() )
{
@@ -277,7 +277,7 @@
if( getLogger().isWarnEnabled() )
{
final String message =
- "ComponentManager exception from parent CM
during lookup.";
+ "ComponentLocator exception from parent CM
during lookup.";
getLogger().warn( message, e );
}
// ignore. If the exception is thrown, we try to
@@ -327,7 +327,7 @@
}
else
{
- getLogger().debug( "Component requested without a
RoleManager set.\nThat means this ComponentManager was not configured." );
+ getLogger().debug( "Component requested without a
RoleManager set.\nThat means thisComponentDirectoryr was not configured." );
}
}
@@ -386,7 +386,7 @@
}
/**
* Configure the ComponentManager.
*/
public void configure( final Configuration configuration )
throws ConfigurationException
@@ -529,7 +529,7 @@
{
// ThreadSafe components will always be using a
ThreadSafeComponentHandler,
// they will only have a single entry in the m_componentMapping
map which
- // should not be removed until the ComponentManager is
disposed. All
+ // should not be removed until the ComponentLocator is
disposed. All
// other components have an entry for each instance which
should be
// removed.
if( !( handler instanceof ThreadSafeComponentHandler ) )
@@ -616,7 +616,7 @@
{
if( m_initialized )
{
- throw new ComponentException( "Cannot add components to an
initialized ComponentManager", null );
+ throw new ComponentException( "Cannot add components to an
initialized ComponentLocator", null );
}
try
@@ -656,7 +656,7 @@
{
if( m_initialized )
{
- throw new IllegalStateException( "Cannot add components to an
initialized ComponentManager" );
+ throw new IllegalStateException( "Cannot add components to an
initialized ComponentLocator" );
}
try
@@ -45,7 +45,7 @@
LogKitManageable
{
- /** The parent ComponentManager */
+ /** The parent ComponentLocator */
private final ComponentManager m_parentManager;
/** The classloader used for this system. */
@@ -72,19 +72,19 @@
/** Is the Manager initialized? */
private boolean m_initialized;
- /** Create the ComponentManager */
+ /** Create the ComponentLocator */
public ExcaliburComponentManager()
{
@@ -72,19 +72,19 @@
this( null, Thread.currentThread().getContextClassLoader() );
}
- /** Create the ComponentManager with a Classloader */
+ /** Create the ComponentLocator with a Classloader */
public ExcaliburComponentManager( final ClassLoader loader )
{
@@ -99,7 +99,7 @@
m_parentManager = manager;
}
- /** Create the ComponentManager with a parent ComponentManager */
+ /** Create the ComponentLocator with a parent ComponentLocator */
public ExcaliburComponentManager( final ComponentManager manager )
{
@@ -386,7 +386,7 @@
}
/**
- * Configure the ComponentManager.
+ * Configure the ComponentLocator.
*/
public void configure( final Configuration configuration )
1.7 +5 -5
jakarta-avalon-excalibur/component/src/java/org/apache/avalon/excalibur/component/ExcaliburComponentSelector.java
--
To unsubscribe, e-mail: <mailto:[EMAIL PROTECTED]>
For additional commands, e-mail: <mailto:[EMAIL PROTECTED]>